instrumenttools.BassSaxophone
=============================

.. abjad-lineage:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone

.. autoclass:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassSaxophone.BassSaxophone.BassSaxophone.__repr__
   :noindex:
